import {Card, Breadcrumb, Form, Button, Radio, Input, Upload, Space, Select, message} from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { Link } from 'react-router-dom'
import ReactQuill from 'react-quill'
import 'react-quill/dist/quill.snow.css'
import './index.scss'
import { useState, useEffect } from 'react'

import { request } from '@/utils'
import { createArticleAPI, getChannelsAPI, getArticleById, updateArticleAPI } from '@/apis/article'

import { useRef } from 'react'

import { useSearchParams } from 'react-router-dom'

const { Option } = Select

const Publish = () => {
    
    // 频道列表
    const [channels, setChannels] = useState([])

    // 调用接口
    useEffect(() => {
      async function fetchChannels() {
          const res = await getChannelsAPI()
          setChannels(res.data.channels)
    } fetchChannels()}, [])

    // 发布文章
  // 提交表单
  const onFinish = (formValue) => {
    console.log(formValue)
    // 校验封面类型imageType是否和实际的图片列表imageList数量是相等的
    if (imageList.length !== imageType) return message.warning('封面类型和图片数量不匹配')
    const { title, content, channel_id } = formValue
    // 1. 按照接口文档的格式处理收集到的表单数据
    const reqData = {
      title,
      content,
      cover: {
        type: imageType, // 封面模式
        // 这里的url处理逻辑只是在新增时候的逻辑
        // 编辑的时候需要做处理
        images: imageList.map(item => {
          if (item.response) {
            return item.response.data.url
          } else {
            return item.url
          }
        }) // 图片列表
      },
      channel_id
    }
    // 2. 调用接口提交
    // 处理调用不同的接口 新增 - 新增接口  编辑状态 - 更新接口  id
    if (articleId) {
      // 更新接口
      updateArticleAPI({ ...reqData, id: articleId })
    } else {
      createArticleAPI(reqData)
    }
  }


    const cacheImageList = useRef([])
    // 上传图片
    const [imageList, setImageList] = useState([])
    const onChange = (info) => {
      setImageList(info.fileList)
      cacheImageList.current = info.fileList
    }

    
    // 控制图片Type
    const [imageType, setImageType] = useState(1)
    

    const onTypeChange = (e) => {
      console.log(e)
      const type = e.target.value
      setImageType(e.target.value)
      if (type === 1) {
        // 单图，截取第一张展示
        const imgList = cacheImageList.current[0] ? [cacheImageList.current[0]] : []
        setImageList(imgList)
      } else if (type === 3) {
        // 三图，取所有图片展示
        setImageList(cacheImageList.current)
      }
    }

  // 回填数据
  const [searchParams] = useSearchParams()
  const articleId = searchParams.get('id')
  const [form] = Form.useForm()
  useEffect(() => {
    async function getArticleDetail () {
      const res = await getArticleById(articleId)
      const data = res.data
      const { cover } = data
      form.setFieldsValue({
        ...data,
        type: cover.type
      })

      // 回填图片列表
      setImageType(cover.type)
      // 显示图片({url:url})
      setImageList(cover.images.map(url => {
        return { url }
      }))
    }
    if (articleId) {
      // 拉取数据回显
      getArticleDetail()
    }
  }, [articleId, form])






return (
  <div className="publish">
    <Card
      title={
        <Breadcrumb items={[
          { title: <Link to={'/'}>首页</Link> },
          { title: `${articleId ? '编辑文章' : '发布文章'}` },
        ]}/>}
    >
      <Form
        labelCol={{ span: 4 }}
        wrapperCol={{ span: 16 }}
        initialValues={{ type: 1 }}
        onFinish={ onFinish }
        form={form}
      >
        <Form.Item
          label="标题"
          name="title"
          rules={[{ required: true, message: '请输入文章标题' }]}
        >
          <Input placeholder="请输入文章标题" style={{ width: 400 }} />
        </Form.Item>
        <Form.Item
          label="频道"
          name="channel_id"
          rules={[{ required: true, message: '请选择文章频道' }]}
        >
          <Select placeholder="请选择文章频道" style={{ width: 400 }}>
            {channels.map(item => (
                <Option key={item.id} value={item.id}>
                    {item.name}
                </Option>
            ))}
          </Select>
        </Form.Item>
        <Form.Item label="封面">
          <Form.Item name="type">
            <Radio.Group onChange={onTypeChange}>
              <Radio value={1}>单图</Radio>
              <Radio value={3}>三图</Radio>
              <Radio value={0}>无图</Radio>
            </Radio.Group>
          </Form.Item>
          {imageType > 0 &&
          <Upload
            listType="picture-card"
            showUploadList
            action={'http://geek.itheima.net/v1_0/upload'}
            name='image'
            onChange={onChange}
            maxCount={imageType}
            multiple={imageType > 1}
            fileList={imageList}
          >
            <div style={{ marginTop: 8 }}>
              <PlusOutlined />
            </div>
          </Upload>
          }
        </Form.Item>
        <Form.Item
            label="内容"
            name="content"
            rules={[{ required: true, message: '请输入文章内容' }]}
        >
            <ReactQuill
                className="publish-quill"
                theme="snow"
                placeholder="请输入文章内容"
            />
        </Form.Item>

        <Form.Item wrapperCol={{ offset: 4 }}>
          <Space>
            <Button size="large" type="primary" htmlType="submit">
              {articleId ? '更新文章' : '发布文章'}
            </Button>
          </Space>
        </Form.Item>
      </Form>
    </Card>
  </div>
)
}

export default Publish
