import { createSlice } from '@reduxjs/toolkit'

import { getToken, setToken as _setToken, clearToken as _clearToken } from '@/utils'
import { getProfileAPI, loginAPI } from '@/apis/user'

const userStore = createSlice({
  name: 'user',
  // 数据状态
  initialState: {
    token: getToken() || '',
    userInfo: {}
  },
  // 同步修改方法
  reducers: {
    setToken (state, action) {
      state.token = action.payload
      // 存入本地
      _setToken(state.token)
    },
    setUserInfo (state, action){
      state.userInfo = action.payload
    },
    clearToken (state) {
      state.token = ''
      state.userInfo = {}
      _clearToken()
    }
  }
})

// 解构出actionCreater
const { setToken, setUserInfo, clearToken } = userStore.actions

// 获取reducer函数
const userReducer = userStore.reducer

// 异步方法封装
const fetchLogin = (loginForm) => {
  return async (dispatch) => {
    const res = await loginAPI(loginForm)
    dispatch(setToken(res.data.token))
  }
}

const fetchUserInfo = () => {
  return async (dispatch) => {
    const res = await getProfileAPI()
    dispatch(setUserInfo(res.data))
  }
}

export { fetchLogin, fetchUserInfo, clearToken }

export default userReducer
